@@ -1,6 +1,9 @@
 package http
 
 import (
+	"bytes"
+	"io"
+	"os"
 	"strings"
 
 	"github.com/pkg/errors"
@@ -23,17 +26,25 @@ type HttpMultiFormatOptions struct {
 	InputFile string
 	// InputMode is the mode of input
 	InputMode string
+
+	// optional input reader
+	InputContents string
 }
 
 // HttpInputProvider implements an input provider for nuclei that loads
 // inputs from multiple formats like burp, openapi, postman,proxify, etc.
 type HttpInputProvider struct {
 	format    formats.Format
+	inputData []byte
 	inputFile string
 	count     int64
 }
 
 // NewHttpInputProvider creates a new input provider for nuclei from a file
+// or an input string
+//
+// The first preference is given to input file if provided
+// otherwise it will use the input string
 func NewHttpInputProvider(opts *HttpMultiFormatOptions) (*HttpInputProvider, error) {
 	var format formats.Format
 	for _, provider := range providersList {
@@ -48,14 +59,40 @@ func NewHttpInputProvider(opts *HttpMultiFormatOptions) (*HttpInputProvider, err
 	// Do a first pass over the input to identify any errors
 	// and get the count of the input file as well
 	count := int64(0)
-	parseErr := format.Parse(opts.InputFile, func(request *types.RequestResponse) bool {
+	var inputFile *os.File
+	var inputReader io.Reader
+	if opts.InputFile != "" {
+		file, err := os.Open(opts.InputFile)
+		if err != nil {
+			return nil, errors.Wrap(err, "could not open input file")
+		}
+		inputFile = file
+		inputReader = file
+	} else {
+		inputReader = strings.NewReader(opts.InputContents)
+	}
+	defer func() {
+		if inputFile != nil {
+			inputFile.Close()
+		}
+	}()
+
+	data, err := io.ReadAll(inputReader)
+	if err != nil {
+		return nil, errors.Wrap(err, "could not read input file")
+	}
+	if len(data) == 0 {
+		return nil, errors.New("input file is empty")
+	}
+
+	parseErr := format.Parse(bytes.NewReader(data), func(request *types.RequestResponse) bool {
 		count++
 		return false
-	})
+	}, opts.InputFile)
 	if parseErr != nil {
 		return nil, errors.Wrap(parseErr, "could not parse input file")
 	}
-	return &HttpInputProvider{format: format, inputFile: opts.InputFile, count: count}, nil
+	return &HttpInputProvider{format: format, inputData: data, inputFile: opts.InputFile, count: count}, nil
 }
 
 // Count returns the number of items for input provider
@@ -65,12 +102,12 @@ func (i *HttpInputProvider) Count() int64 {
 
 // Iterate over all inputs in order
 func (i *HttpInputProvider) Iterate(callback func(value *contextargs.MetaInput) bool) {
-	err := i.format.Parse(i.inputFile, func(request *types.RequestResponse) bool {
+	err := i.format.Parse(bytes.NewReader(i.inputData), func(request *types.RequestResponse) bool {
 		metaInput := contextargs.NewMetaInput()
 		metaInput.ReqResp = request
 		metaInput.Input = request.URL.String()
 		return callback(metaInput)
-	})
+	}, i.inputFile)
 	if err != nil {
 		gologger.Warning().Msgf("Could not parse input file while iterating: %s\n", err)
 	}
